==> PyUtilib-5.7.0.tar.gz: PyUtilib-5.7.0/README.md <==
[![Travis Build Status](https://travis-ci.org/PyUtilib/pyutilib.png?branch=master)](https://travis-ci.org/PyUtilib/pyutilib)
[![Appveyor Build status](https://ci.appveyor.com/api/projects/status/c8dh5o1blp0sycr6/branch/master?svg=true)](https://ci.appveyor.com/project/WilliamHart/pyutilib/branch/master)
[![codecov.io](https://codecov.io/github/PyUtilib/pyutilib/coverage.svg?branch=master)](https://codecov.io/github/PyUtilib/pyutilib?branch=master)
[![Scrutinizer Code Quality](https://scrutinizer-ci.com/g/PyUtilib/pyutilib/badges/quality-score.png?b=master)](https://scrutinizer-ci.com/g/PyUtilib/pyutilib/?branch=master)
[![Depsy Software Impact](http://depsy.org/api/package/pypi/PyUtilib/badge.svg)](http://depsy.org/package/python/PyUtilib)
[![Project Status: Active – The project has reached a stable, usable state and is being actively developed.](http://www.repostatus.org/badges/latest/active.svg)](http://www.repostatus.org/#active)

## PyUtilib Overview

The PyUtilib project supports a collection of Python utilities,
including a well-developed component architecture and extensions
to the PyUnit testing framework. PyUtilib has been developed to
support several Python-centric projects, especially
[Pyomo](http://pyomo.org).

PyUtilib is available under the BSD License.

### Installation

#### PyPI [![PyPI](https://img.shields.io/pypi/v/pyutilib.svg?maxAge=2592000)]() 

    pip install pyutilib
    
#### BinStar [![Binstar Badge](https://anaconda.org/conda-forge/pyutilib/badges/version.svg)](https://anaconda.org/conda-forge/pyutilib) [![Binstar Badge](https://anaconda.org/conda-forge/pyutilib/badges/downloads.svg)](https://anaconda.org/conda-forge/pyutilib)

    conda install -c https://conda.anaconda.org/conda-forge pyutilib

### Getting Help

* [PyUtilib Forum](https://groups.google.com/forum/?hl=en#!forum/pyutilib-forum)
* [Add a Ticket](https://github.com/PyUtilib/pyutilib/issues/new)
* [Find a Ticket](https://github.com/PyUtilib/pyutilib/issues) and **Vote On It**!

### Developers

PyUtilib development moved to this repository in October, 2015 from
Sandia National Laboratories. Developer discussions are hosted by [google groups](https://groups.google.com/forum/#!forum/pyutilib-developers).


By contributing to this software project, you are agreeing to the following terms and conditions for your contributions:

1. You agree your contributions are submitted under the BSD license. 
2. You represent you are authorized to make the contributions and grant the license. If your employer has rights to intellectual property that includes your contributions, you represent that you have received permission to make contributions and grant the required license on behalf of that employer.

==> PyUtilib-5.7.2.tar.gz: PyUtilib-5.7.2/README.md <==
[![Travis Build Status](https://travis-ci.org/PyUtilib/pyutilib.png?branch=master)](https://travis-ci.org/PyUtilib/pyutilib)
[![Appveyor Build status](https://ci.appveyor.com/api/projects/status/c8dh5o1blp0sycr6/branch/master?svg=true)](https://ci.appveyor.com/project/WilliamHart/pyutilib/branch/master)
[![codecov.io](https://codecov.io/github/PyUtilib/pyutilib/coverage.svg?branch=master)](https://codecov.io/github/PyUtilib/pyutilib?branch=master)
[![Scrutinizer Code Quality](https://scrutinizer-ci.com/g/PyUtilib/pyutilib/badges/quality-score.png?b=master)](https://scrutinizer-ci.com/g/PyUtilib/pyutilib/?branch=master)
[![Depsy Software Impact](http://depsy.org/api/package/pypi/PyUtilib/badge.svg)](http://depsy.org/package/python/PyUtilib)
[![Project Status: Active - The project has reached a stable, usable state and is being actively developed.](http://www.repostatus.org/badges/latest/active.svg)](http://www.repostatus.org/#active)

## PyUtilib Overview

The PyUtilib project supports a collection of Python utilities,
including a well-developed component architecture and extensions
to the PyUnit testing framework. PyUtilib has been developed to
support several Python-centric projects, especially
[Pyomo](http://pyomo.org).

PyUtilib is available under the BSD License.

### Installation

#### PyPI [![PyPI](https://img.shields.io/pypi/v/pyutilib.svg?maxAge=2592000)]() 

    pip install pyutilib
    
#### BinStar [![Binstar Badge](https://anaconda.org/conda-forge/pyutilib/badges/version.svg)](https://anaconda.org/conda-forge/pyutilib) [![Binstar Badge](https://anaconda.org/conda-forge/pyutilib/badges/downloads.svg)](https://anaconda.org/conda-forge/pyutilib)

    conda install -c https://conda.anaconda.org/conda-forge pyutilib

### Getting Help

* [PyUtilib Forum](https://groups.google.com/forum/?hl=en#!forum/pyutilib-forum)
* [Add a Ticket](https://github.com/PyUtilib/pyutilib/issues/new)
* [Find a Ticket](https://github.com/PyUtilib/pyutilib/issues) and **Vote On It**!

### Developers

PyUtilib development moved to this repository in October, 2015 from
Sandia National Laboratories. Developer discussions are hosted by [google groups](https://groups.google.com/forum/#!forum/pyutilib-developers).


By contributing to this software project, you are agreeing to the following terms and conditions for your contributions:

1. You agree your contributions are submitted under the BSD license. 
2. You represent you are authorized to make the contributions and grant the license. If your employer has rights to intellectual property that includes your contributions, you represent that you have received permission to make contributions and grant the required license on behalf of that employer.
